@@ -59,7 +59,7 @@ pub struct Declaration {
     pub name: DeclarationName,
     pub value: Vec<Value>,
     /// The span includes `!`
-    pub important: Option<Span>,
+    pub important: Option<ImportantFlag>,
 }
 
 #[ast_node]
@@ -69,3 +69,9 @@ pub enum DeclarationName {
     #[tag("DashedIdent")]
     DashedIdent(DashedIdent),
 }
+
+#[ast_node("ImportantFlag")]
+pub struct ImportantFlag {
+    pub span: Span,
+    pub value: Ident,
+}
